@@ -2,7 +2,7 @@ from .DefBuilder import DefBuilder
 from .DocModel import DocModel
 from .LatexBuilder import LatexBuilder
 from .TemplateLoader import TemplateLoader
-from .TemplateOptions import TemplateOptions
+from .TemplateOptions import TemplateOptions, Tag
 from .TemplateRenderer import TemplateRenderer
 from .PublicTemplateLoader import PublicTemplateLoader
 from .version import __version__
